@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "selectrum-prescient" "6.3.2"
+(define-package "selectrum-prescient" "20250816.19"
   "Prescient.el + Selectrum."
   '((emacs     "25.1")
     (prescient "6.1.0")
